@@ -1,9 +1,9 @@
 from __future__ import absolute_import, unicode_literals
 
 import os
+import sys
 from collections import OrderedDict
 
-from virtualenv.info import WIN_CPYTHON_2
 from virtualenv.util.path import Path
 from virtualenv.util.six import ensure_text
 
@@ -17,10 +17,11 @@ class PythonActivator(ViaTemplateActivator):
     def replacements(self, creator, dest_folder):
         replacements = super(PythonActivator, self).replacements(creator, dest_folder)
         lib_folders = OrderedDict((os.path.relpath(str(i), str(dest_folder)), None) for i in creator.libs)
+        win_py2 = creator.interpreter.platform == "win32" and creator.interpreter.version_info.major == 2
         replacements.update(
             {
                 "__LIB_FOLDERS__": ensure_text(os.pathsep.join(lib_folders.keys())),
-                "__DECODE_PATH__": ("yes" if WIN_CPYTHON_2 else ""),
+                "__DECODE_PATH__": ("yes" if win_py2 else ""),
             }
         )
         return replacements
@@ -29,5 +30,6 @@ class PythonActivator(ViaTemplateActivator):
     def _repr_unicode(creator, value):
         py2 = creator.interpreter.version_info.major == 2
         if py2:  # on Python 2 we need to encode this into explicit utf-8, py3 supports unicode literals
-            value = ensure_text(repr(value.encode("utf-8"))[1:-1])
+            start = 2 if sys.version_info[0] == 3 else 1
+            value = ensure_text(repr(value.encode("utf-8"))[start:-1])
         return value
