@@ -29,7 +29,15 @@ def zipapp_build_env(tmp_path_factory):
                 try:
                     # create a virtual environment which is also guaranteed to contain a recent enough pip (bundled)
                     session = cli_run(
-                        ["-vvv", "-p", "{}3.{}".format(impl, version), "--activators", "", str(create_env_path)]
+                        [
+                            "-vvv",
+                            "-p",
+                            "{}3.{}".format(impl, version),
+                            "--activators",
+                            "",
+                            str(create_env_path),
+                            "--no-download",
+                        ]
                     )
                     exe = str(session.creator.exe)
                     found = True
@@ -75,7 +83,6 @@ def call_zipapp(zipapp, monkeypatch, tmp_path, zipapp_test_env, temp_app_data):
     return _run
 
 
-@pytest.mark.timeout(timeout=300)
 def test_zipapp_help(call_zipapp, capsys):
     call_zipapp("-h")
     out, err = capsys.readouterr()
